"use strict";

var _keys = require("babel-runtime/core-js/object/keys");

var _keys2 = _interopRequireDefault(_keys);

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.each = each;
exports.when = when;

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

/**
 * Template extendable object, all the templates are stored here.
 * @type {Object}
 */
exports.default = Template = {};

/**
 * Run through a list or object with the iteratee method.
 * @param  {Any}      list     The list or object to be used.
 * @param  {Function} iteratee The method to use on each element.
 * @param  {Object}   context  The context to use in the iteratee.
 * @return {Array}             An array containing the return of all iteratee.
 */

function each(list, iteratee, context) {
  var keys = (0, _keys2.default)(list);
  var max = keys.length - 1;
  var arr = keys.map(function (key, index) {
    return iteratee.call(context, list[key], key, index, max);
  });
  arr.__proto__ = {
    else: function _else(elseblock) {
      if (this.length == 0) {
        return elseblock;
      }
      return this;
    }
  };
  return arr;
}

/**
 * Show block if truth, hide if falsey.
 * @param  {Boolean}  truth Expression
 * @param  {Any}      block Function, String or React Element.
 * @return {Any}            Returns the block if truth.
 */
function when(truth, block) {
  var obj = {
    else: function _else(elseblock) {
      return !truth ? elseblock : block;
    }
  };
  if (truth) {
    obj.__proto__ = block;
  }
  return obj;
}